/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * EnvironmentVariablesHandler.java
 * Copyright (C) 2018 University of Waikato, Hamilton, NZ
 */

package adams.core.management;

import adams.core.base.BaseKeyValuePair;
import adams.core.option.OptionHandler;

/**
 * Interface for classes that handle environment variables.
 *
 * @author FracPete (fracpete at waikato dot ac dot nz)
 */
public interface EnvironmentVariablesHandler
  extends OptionHandler {

  /**
   * Sets the environment variables to overlay on top of the current ones.
   *
   * @param value	the environment variables
   */
  public void setEnvVars(BaseKeyValuePair[] value);

  /**
   * Returns the environment variables to overlay on top of the current ones.
   *
   * @return 		the environment variables
   */
  public BaseKeyValuePair[] getEnvVars();

  /**
   * Returns the tip text for this property.
   *
   * @return		tip text for this property suitable for
   *             	displaying in the GUI or for listing the options.
   */
  public String envVarsTipText();
}
