/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * WindowDuplicateInWindow.java
 * Copyright (C) 2014-2019 University of Waikato, Hamilton, New Zealand
 */
package adams.gui.flow.menu;

import adams.gui.application.ChildFrame;
import adams.gui.core.GUIHelper;
import adams.gui.flow.FlowEditorPanel;

import java.awt.event.ActionEvent;

/**
 * Duplicates the flow in a new window.
 * 
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision$
 */
public class WindowDuplicateInWindow
  extends AbstractFlowEditorMenuItemAction {

  /** for serialization. */
  private static final long serialVersionUID = 5235570137451285010L;

  /**
   * Returns the caption of this action.
   * 
   * @return		the caption, null if not applicable
   */
  @Override
  protected String getTitle() {
    return "Duplicate in new window";
  }
  
  /**
   * Invoked when an action occurs.
   */
  @Override
  protected void doActionPerformed(ActionEvent e) {
    FlowEditorPanel 	panel;
    ChildFrame 		oldFrame;
    ChildFrame 		newFrame;

    panel    = null;
    oldFrame = (ChildFrame) GUIHelper.getParent(m_State, ChildFrame.class);
    if (oldFrame != null) {
      newFrame = oldFrame.getNewWindow();
      newFrame.setVisible(true);
      panel  = (FlowEditorPanel) newFrame.getContentPane().getComponent(0);
    }

    // copy information
    if (panel != null) {
      panel.setCurrentDirectory(m_State.getCurrentDirectory());
      panel.newTab();
      panel.setCurrentFlow(m_State.getCurrentFlow());
      panel.setCurrentFile(m_State.getCurrentFile());
      panel.getCurrentPanel().setTitle("Copy of " + m_State.getCurrentPanel().getTitle());
      panel.setModified(m_State.isModified());
      panel.update();
      panel.requestFocus();
    }
  }

  /**
   * Performs the actual update of the state of the action.
   */
  @Override
  protected void doUpdate() {
    setEnabled(m_State.hasCurrentPanel());
  }
}
